# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.

from __future__ import absolute_import


from .work_request_client import WorkRequestClient
from .work_request_client_composite_operations import WorkRequestClientCompositeOperations
from . import models

__all__ = ["WorkRequestClient", "WorkRequestClientCompositeOperations", "models"]
