# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateClusterNetworkDetails(object):
    """
    The data to create a cluster network.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateClusterNetworkDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateClusterNetworkDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateClusterNetworkDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateClusterNetworkDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateClusterNetworkDetails.
        :type freeform_tags: dict(str, str)

        :param instance_pools:
            The value to assign to the instance_pools property of this CreateClusterNetworkDetails.
        :type instance_pools: list[CreateClusterNetworkInstancePoolDetails]

        :param placement_configuration:
            The value to assign to the placement_configuration property of this CreateClusterNetworkDetails.
        :type placement_configuration: ClusterNetworkPlacementConfigurationDetails

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'instance_pools': 'list[CreateClusterNetworkInstancePoolDetails]',
            'placement_configuration': 'ClusterNetworkPlacementConfigurationDetails'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'instance_pools': 'instancePools',
            'placement_configuration': 'placementConfiguration'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._instance_pools = None
        self._placement_configuration = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateClusterNetworkDetails.
        The `OCID`__ of the compartment
        containing the cluster network.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateClusterNetworkDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateClusterNetworkDetails.
        The `OCID`__ of the compartment
        containing the cluster network.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateClusterNetworkDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateClusterNetworkDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateClusterNetworkDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateClusterNetworkDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateClusterNetworkDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateClusterNetworkDetails.
        A user-friendly name for the cluster network. Does not have to be unique, and it's
        changeable. Avoid entering confidential information.


        :return: The display_name of this CreateClusterNetworkDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateClusterNetworkDetails.
        A user-friendly name for the cluster network. Does not have to be unique, and it's
        changeable. Avoid entering confidential information.


        :param display_name: The display_name of this CreateClusterNetworkDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateClusterNetworkDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateClusterNetworkDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateClusterNetworkDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateClusterNetworkDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def instance_pools(self):
        """
        **[Required]** Gets the instance_pools of this CreateClusterNetworkDetails.
        The data to create the instance pools in the cluster network.

        Each cluster network can have one instance pool.


        :return: The instance_pools of this CreateClusterNetworkDetails.
        :rtype: list[CreateClusterNetworkInstancePoolDetails]
        """
        return self._instance_pools

    @instance_pools.setter
    def instance_pools(self, instance_pools):
        """
        Sets the instance_pools of this CreateClusterNetworkDetails.
        The data to create the instance pools in the cluster network.

        Each cluster network can have one instance pool.


        :param instance_pools: The instance_pools of this CreateClusterNetworkDetails.
        :type: list[CreateClusterNetworkInstancePoolDetails]
        """
        self._instance_pools = instance_pools

    @property
    def placement_configuration(self):
        """
        **[Required]** Gets the placement_configuration of this CreateClusterNetworkDetails.
        The placement configuration for the instance pools in the cluster network.


        :return: The placement_configuration of this CreateClusterNetworkDetails.
        :rtype: ClusterNetworkPlacementConfigurationDetails
        """
        return self._placement_configuration

    @placement_configuration.setter
    def placement_configuration(self, placement_configuration):
        """
        Sets the placement_configuration of this CreateClusterNetworkDetails.
        The placement configuration for the instance pools in the cluster network.


        :param placement_configuration: The placement_configuration of this CreateClusterNetworkDetails.
        :type: ClusterNetworkPlacementConfigurationDetails
        """
        self._placement_configuration = placement_configuration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
