# coding: utf-8
# Modified Work: Copyright (c) 2018, 2020, Oracle and/or its affiliates. All rights reserved.
# Copyright (c) 2013-2018, Kim Davies. All rights reserved.

from .package_data import __version__
from .core import *
